@@ -142,3 +142,17 @@ class AzureAPI(BaseMicrosoftAPI):
                   f'applicationGateways?api-version=2021-05-01'
             app_gateways += self.call_api(url)
         return app_gateways
+
+    def list_databricks_workspaces(self, subscriptions=None):
+        if subscriptions is None:
+            if self.subscriptions is None:
+                self.subscriptions = self.subscriptionIds()
+            subscriptions = self.subscriptions
+
+        databricks_workspaces = []
+        for subscription in subscriptions:
+            url = f'https://management.azure.com/subscriptions/{subscription}'\
+                  f'/providers/Microsoft.Databricks/'\
+                  f'workspaces?api-version=2018-04-01'
+            databricks_workspaces += self.call_api(url)
+        return databricks_workspaces
